/* contacts-types.c generated by valac 0.32.0.15-114e9, the Vala compiler
 * generated from contacts-types.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 8 -*- */
/*
 * Copyright (C) 2011 Alexander Larsson <alexl@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <config.h>
#include <folks/folks.h>
#include <gee.h>
#include <gdk/gdk.h>


#define CONTACTS_TYPE_TYPESET (contacts_typeset_get_type ())
#define CONTACTS_TYPESET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_TYPESET, ContactsTypeSet))
#define CONTACTS_TYPESET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_TYPESET, ContactsTypeSetClass))
#define CONTACTS_IS_TYPESET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_TYPESET))
#define CONTACTS_IS_TYPESET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_TYPESET))
#define CONTACTS_TYPESET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_TYPESET, ContactsTypeSetClass))

typedef struct _ContactsTypeSet ContactsTypeSet;
typedef struct _ContactsTypeSetClass ContactsTypeSetClass;
typedef struct _ContactsTypeSetPrivate ContactsTypeSetPrivate;

#define CONTACTS_TYPESET_TYPE_DATA (contacts_typeset_data_get_type ())
#define CONTACTS_TYPESET_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPESET_TYPE_DATA, ContactsTypeSetData))
#define CONTACTS_TYPESET_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPESET_TYPE_DATA, ContactsTypeSetDataClass))
#define CONTACTS_TYPESET_IS_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPESET_TYPE_DATA))
#define CONTACTS_TYPESET_IS_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPESET_TYPE_DATA))
#define CONTACTS_TYPESET_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPESET_TYPE_DATA, ContactsTypeSetDataClass))

typedef struct _ContactsTypeSetData ContactsTypeSetData;
typedef struct _ContactsTypeSetDataClass ContactsTypeSetDataClass;

#define CONTACTS_TYPESET_TYPE_INIT_DATA (contacts_typeset_init_data_get_type ())
typedef struct _ContactsTypeSetInitData ContactsTypeSetInitData;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _ContactsTypeSetDataPrivate ContactsTypeSetDataPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define CONTACTS_TYPE_TYPECOMBO (contacts_typecombo_get_type ())
#define CONTACTS_TYPECOMBO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_TYPECOMBO, ContactsTypeCombo))
#define CONTACTS_TYPECOMBO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_TYPECOMBO, ContactsTypeComboClass))
#define CONTACTS_IS_TYPECOMBO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_TYPECOMBO))
#define CONTACTS_IS_TYPECOMBO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_TYPECOMBO))
#define CONTACTS_TYPECOMBO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_TYPECOMBO, ContactsTypeComboClass))

typedef struct _ContactsTypeCombo ContactsTypeCombo;
typedef struct _ContactsTypeComboClass ContactsTypeComboClass;
typedef struct _ContactsTypeComboPrivate ContactsTypeComboPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ContactsTypeSet {
	GObject parent_instance;
	ContactsTypeSetPrivate * priv;
	GtkListStore* store;
};

struct _ContactsTypeSetClass {
	GObjectClass parent_class;
};

struct _ContactsTypeSetInitData {
	const gchar* display_name_u;
	const gchar* types[3];
};

struct _ContactsTypeSetPrivate {
	GHashTable* display_name_hash;
	GHashTable* vcard_lookup_hash;
	GHashTable* custom_hash;
	GtkTreeIter other_iter;
	GtkTreeIter custom_iter;
};

struct _ContactsTypeSetData {
	GObject parent_instance;
	ContactsTypeSetDataPrivate * priv;
	gchar* display_name;
	GList* init_data;
	GtkTreeIter iter;
	gboolean in_store;
};

struct _ContactsTypeSetDataClass {
	GObjectClass parent_class;
};

struct _ContactsTypeCombo {
	GtkGrid parent_instance;
	ContactsTypeComboPrivate * priv;
	gboolean modified;
};

struct _ContactsTypeComboClass {
	GtkGridClass parent_class;
};

struct _ContactsTypeComboPrivate {
	ContactsTypeSet* type_set;
	GtkComboBox* combo;
	GtkEntry* entry;
	GtkTreeIter last_active;
	gboolean custom_mode;
	gboolean in_manual_change;
};


static gpointer contacts_typeset_parent_class = NULL;
static ContactsTypeSetData* contacts_typeset_custom_dummy;
static ContactsTypeSetData* contacts_typeset_custom_dummy = NULL;
static ContactsTypeSetData* contacts_typeset_other_dummy;
static ContactsTypeSetData* contacts_typeset_other_dummy = NULL;
static ContactsTypeSet* contacts_typeset__general;
static ContactsTypeSet* contacts_typeset__general = NULL;
static ContactsTypeSet* contacts_typeset__email;
static ContactsTypeSet* contacts_typeset__email = NULL;
static ContactsTypeSet* contacts_typeset__phone;
static ContactsTypeSet* contacts_typeset__phone = NULL;
static gpointer contacts_typeset_data_parent_class = NULL;
static gpointer contacts_typecombo_parent_class = NULL;

GType contacts_typeset_get_type (void) G_GNUC_CONST;
static GType contacts_typeset_data_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static GType contacts_typeset_init_data_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static ContactsTypeSetInitData* contacts_typeset_init_data_dup (const ContactsTypeSetInitData* self);
static void contacts_typeset_init_data_free (ContactsTypeSetInitData* self);
#define CONTACTS_TYPESET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CONTACTS_TYPE_TYPESET, ContactsTypeSetPrivate))
enum  {
	CONTACTS_TYPESET_DUMMY_PROPERTY
};
static ContactsTypeSetData* contacts_typeset_data_new (void);
static ContactsTypeSetData* contacts_typeset_data_construct (GType object_type);
#define CONTACTS_TYPESET_X_GOOGLE_LABEL "x-google-label"
#define CONTACTS_TYPESET_MAX_TYPES 3
static ContactsTypeSet* contacts_typeset_new (void);
static ContactsTypeSet* contacts_typeset_construct (GType object_type);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free0_ (gpointer var);
static void _g_free0_ (gpointer var);
static void contacts_typeset_add_data_to_store (ContactsTypeSet* self, ContactsTypeSetData* data, gboolean is_custom);
static void contacts_typeset_add_init_data (ContactsTypeSet* self, ContactsTypeSetInitData* init_data);
static void contacts_typeset_add_init_data_done (ContactsTypeSet* self, gchar** standard_untranslated, int standard_untranslated_length1);
void contacts_typeset_add_custom_label (ContactsTypeSet* self, const gchar* label, GtkTreeIter* iter);
static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self);
static ContactsTypeSetData* contacts_typeset_lookup_data_by_string (ContactsTypeSet* self, const gchar* str);
static ContactsTypeSetData* contacts_typeset_lookup_data (ContactsTypeSet* self, FolksAbstractFieldDetails* detail);
void contacts_typeset_lookup_type (ContactsTypeSet* self, FolksAbstractFieldDetails* detail, GtkTreeIter* iter);
gpointer contacts_utils_get_first (GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, GeeCollection* collection);
void contacts_typeset_lookup_type_by_string (ContactsTypeSet* self, const gchar* type, GtkTreeIter* iter);
void contacts_typeset_type_seen (ContactsTypeSet* self, FolksAbstractFieldDetails* detail);
gchar* contacts_typeset_format_type (ContactsTypeSet* self, FolksAbstractFieldDetails* detail);
void contacts_typeset_update_details (ContactsTypeSet* self, FolksAbstractFieldDetails* details, GtkTreeIter* iter);
gboolean contacts_typeset_is_custom (ContactsTypeSet* self, GtkTreeIter* iter);
ContactsTypeSet* contacts_typeset_get_general (void);
ContactsTypeSet* contacts_typeset_get_email (void);
ContactsTypeSet* contacts_typeset_get_phone (void);
enum  {
	CONTACTS_TYPESET_DATA_DUMMY_PROPERTY
};
static void contacts_typeset_data_finalize (GObject* obj);
static void contacts_typeset_finalize (GObject* obj);
static void _vala_contacts_typeset_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
GType contacts_typecombo_get_type (void) G_GNUC_CONST;
#define CONTACTS_TYPECOMBO_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CONTACTS_TYPE_TYPECOMBO, ContactsTypeComboPrivate))
enum  {
	CONTACTS_TYPECOMBO_DUMMY_PROPERTY
};
ContactsTypeCombo* contacts_typecombo_new (ContactsTypeSet* type_set);
ContactsTypeCombo* contacts_typecombo_construct (GType object_type, ContactsTypeSet* type_set);
static gboolean __lambda39_ (ContactsTypeCombo* self, GtkTreeModel* model, GtkTreeIter* iter);
static gboolean ___lambda39__gtk_tree_view_row_separator_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self);
static void contacts_typecombo_combo_changed (ContactsTypeCombo* self, GtkComboBox* combo);
static void _contacts_typecombo_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static gboolean contacts_typecombo_entry_focus_out_event (ContactsTypeCombo* self, GdkEventFocus* event);
static gboolean _contacts_typecombo_entry_focus_out_event_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static void contacts_typecombo_entry_activate (ContactsTypeCombo* self);
static void _contacts_typecombo_entry_activate_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static gboolean contacts_typecombo_entry_key_release (ContactsTypeCombo* self, GdkEventKey* event);
static gboolean _contacts_typecombo_entry_key_release_gtk_widget_key_release_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static void contacts_typecombo_finish_custom (ContactsTypeCombo* self);
static void contacts_typecombo_set_from_iter (ContactsTypeCombo* self, GtkTreeIter* iter);
void contacts_typecombo_set_active (ContactsTypeCombo* self, FolksAbstractFieldDetails* details);
void contacts_typecombo_set_to (ContactsTypeCombo* self, const gchar* type);
void contacts_typecombo_update_details (ContactsTypeCombo* self, FolksAbstractFieldDetails* details);
static void contacts_typecombo_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const ContactsTypeSetInitData CONTACTS_TYPESET_general_data[2] = {{"Home", {"HOME"}, 3}, {"Work", {"WORK"}, 3}};
static const ContactsTypeSetInitData CONTACTS_TYPESET_email_data[3] = {{"Personal", {"PERSONAL"}, 3}, {"Home", {"HOME"}, 3}, {"Work", {"WORK"}, 3}};

static void _g_object_unref0_ (gpointer var) {
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 222 "contacts-types.c"
}


static void _g_list_free0_ (gpointer var) {
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	(var == NULL) ? NULL : (var = (g_list_free (var), NULL));
#line 229 "contacts-types.c"
}


static void _g_free0_ (gpointer var) {
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	(var == NULL) ? NULL : (var = (g_free (var), NULL));
#line 236 "contacts-types.c"
}


static ContactsTypeSet* contacts_typeset_construct (GType object_type) {
	ContactsTypeSet * self = NULL;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	GHashFunc _tmp3_ = NULL;
	GEqualFunc _tmp4_ = NULL;
	GHashTable* _tmp5_ = NULL;
	GHashFunc _tmp6_ = NULL;
	GEqualFunc _tmp7_ = NULL;
	GHashTable* _tmp8_ = NULL;
	GtkListStore* _tmp9_ = NULL;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self = (ContactsTypeSet*) g_object_new (object_type, NULL);
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = g_str_hash;
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = g_str_equal;
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, NULL, _g_object_unref0_);
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_hash_table_unref0 (self->priv->display_name_hash);
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->display_name_hash = _tmp2_;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = g_str_hash;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = g_str_equal;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp5_ = g_hash_table_new_full (_tmp3_, _tmp4_, NULL, _g_list_free0_);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_hash_table_unref0 (self->priv->vcard_lookup_hash);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->vcard_lookup_hash = _tmp5_;
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp6_ = g_str_hash;
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp7_ = g_str_equal;
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp8_ = g_hash_table_new_full (_tmp6_, _tmp7_, NULL, _g_free0_);
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_hash_table_unref0 (self->priv->custom_hash);
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->custom_hash = _tmp8_;
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp9_ = gtk_list_store_new (2, G_TYPE_STRING, CONTACTS_TYPESET_TYPE_DATA, -1);
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (self->store);
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->store = _tmp9_;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return self;
#line 292 "contacts-types.c"
}


static ContactsTypeSet* contacts_typeset_new (void) {
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return contacts_typeset_construct (CONTACTS_TYPE_TYPESET);
#line 299 "contacts-types.c"
}


static void contacts_typeset_add_data_to_store (ContactsTypeSet* self, ContactsTypeSetData* data, gboolean is_custom) {
	ContactsTypeSetData* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	ContactsTypeSetData* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GtkListStore* _tmp11_ = NULL;
	ContactsTypeSetData* _tmp12_ = NULL;
	GtkTreeIter _tmp13_ = {0};
	ContactsTypeSetData* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	ContactsTypeSetData* _tmp16_ = NULL;
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (data != NULL);
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = data;
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = _tmp0_->in_store;
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp1_) {
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return;
#line 326 "contacts-types.c"
	}
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = data;
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_->in_store = TRUE;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = is_custom;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp3_) {
#line 336 "contacts-types.c"
		GtkListStore* _tmp4_ = NULL;
		ContactsTypeSetData* _tmp5_ = NULL;
		GtkTreeIter _tmp6_ = {0};
		GtkTreeIter _tmp7_ = {0};
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp4_ = self->store;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = data;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp6_ = self->priv->custom_iter;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		gtk_list_store_insert_before (_tmp4_, &_tmp7_, &_tmp6_);
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_->iter = _tmp7_;
#line 351 "contacts-types.c"
	} else {
		GtkListStore* _tmp8_ = NULL;
		ContactsTypeSetData* _tmp9_ = NULL;
		GtkTreeIter _tmp10_ = {0};
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp8_ = self->store;
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_ = data;
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		gtk_list_store_append (_tmp8_, &_tmp10_);
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_->iter = _tmp10_;
#line 364 "contacts-types.c"
	}
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp11_ = self->store;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp12_ = data;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp13_ = _tmp12_->iter;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp14_ = data;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp15_ = _tmp14_->display_name;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp16_ = data;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_list_store_set (_tmp11_, &_tmp13_, 0, _tmp15_, 1, _tmp16_, -1);
#line 380 "contacts-types.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return self ? g_object_ref (self) : NULL;
#line 387 "contacts-types.c"
}


static void contacts_typeset_add_init_data (ContactsTypeSet* self, ContactsTypeSetInitData* init_data) {
	const gchar* dn = NULL;
	ContactsTypeSetInitData* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	ContactsTypeSetData* data = NULL;
	GHashTable* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gconstpointer _tmp5_ = NULL;
	ContactsTypeSetData* _tmp6_ = NULL;
	ContactsTypeSetData* _tmp7_ = NULL;
	ContactsTypeSetData* _tmp16_ = NULL;
	ContactsTypeSetInitData* _tmp17_ = NULL;
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = init_data;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = (*_tmp0_).display_name_u;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = g_dgettext (GETTEXT_PACKAGE, _tmp1_);
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	dn = _tmp2_;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = self->priv->display_name_hash;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = dn;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp5_ = g_hash_table_lookup (_tmp3_, _tmp4_);
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp6_ = _g_object_ref0 ((ContactsTypeSetData*) _tmp5_);
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	data = _tmp6_;
#line 82 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp7_ = data;
#line 82 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp7_ == NULL) {
#line 428 "contacts-types.c"
		ContactsTypeSetData* _tmp8_ = NULL;
		ContactsTypeSetData* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GHashTable* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		ContactsTypeSetData* _tmp14_ = NULL;
		ContactsTypeSetData* _tmp15_ = NULL;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp8_ = contacts_typeset_data_new ();
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (data);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		data = _tmp8_;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_ = data;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp10_ = dn;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_free0 (_tmp9_->display_name);
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_->display_name = _tmp11_;
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp12_ = self->priv->display_name_hash;
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp13_ = dn;
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp14_ = data;
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp15_ = _g_object_ref0 (_tmp14_);
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		g_hash_table_insert (_tmp12_, _tmp13_, _tmp15_);
#line 463 "contacts-types.c"
	}
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp16_ = data;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp17_ = init_data;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp16_->init_data = g_list_append (_tmp16_->init_data, _tmp17_);
#line 471 "contacts-types.c"
	{
		gint j = 0;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		j = 0;
#line 476 "contacts-types.c"
		{
			gboolean _tmp18_ = FALSE;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp18_ = TRUE;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			while (TRUE) {
#line 483 "contacts-types.c"
				gboolean _tmp20_ = FALSE;
				gint _tmp21_ = 0;
				const gchar* type = NULL;
				ContactsTypeSetInitData* _tmp25_ = NULL;
				gint _tmp26_ = 0;
				const gchar* _tmp27_ = NULL;
				GList* l = NULL;
				GHashTable* _tmp28_ = NULL;
				const gchar* _tmp29_ = NULL;
				gconstpointer _tmp30_ = NULL;
				GList* _tmp31_ = NULL;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				if (!_tmp18_) {
#line 497 "contacts-types.c"
					gint _tmp19_ = 0;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp19_ = j;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					j = _tmp19_ + 1;
#line 503 "contacts-types.c"
				}
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp18_ = FALSE;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp21_ = j;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				if (_tmp21_ < CONTACTS_TYPESET_MAX_TYPES) {
#line 511 "contacts-types.c"
					ContactsTypeSetInitData* _tmp22_ = NULL;
					gint _tmp23_ = 0;
					const gchar* _tmp24_ = NULL;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp22_ = init_data;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp23_ = j;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp24_ = (*_tmp22_).types[_tmp23_];
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp20_ = _tmp24_ != NULL;
#line 523 "contacts-types.c"
				} else {
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp20_ = FALSE;
#line 527 "contacts-types.c"
				}
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				if (!_tmp20_) {
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					break;
#line 533 "contacts-types.c"
				}
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp25_ = init_data;
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp26_ = j;
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp27_ = (*_tmp25_).types[_tmp26_];
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				type = _tmp27_;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp28_ = self->priv->vcard_lookup_hash;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp29_ = type;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp30_ = g_hash_table_lookup (_tmp28_, _tmp29_);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				l = (GList*) _tmp30_;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp31_ = l;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				if (_tmp31_ != NULL) {
#line 555 "contacts-types.c"
					ContactsTypeSetInitData* _tmp32_ = NULL;
#line 94 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp32_ = init_data;
#line 94 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					l = g_list_append (l, _tmp32_);
#line 561 "contacts-types.c"
				} else {
					GList* l2 = NULL;
					ContactsTypeSetInitData* _tmp33_ = NULL;
					GHashTable* _tmp34_ = NULL;
					const gchar* _tmp35_ = NULL;
					GList* _tmp36_ = NULL;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					l2 = NULL;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp33_ = init_data;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					l2 = g_list_append (l2, _tmp33_);
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp34_ = self->priv->vcard_lookup_hash;
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp35_ = type;
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp36_ = l2;
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					l2 = NULL;
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					g_hash_table_insert (_tmp34_, _tmp35_, _tmp36_);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_g_list_free0 (l2);
#line 586 "contacts-types.c"
				}
			}
		}
	}
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (data);
#line 593 "contacts-types.c"
}


static void contacts_typeset_add_init_data_done (ContactsTypeSet* self, gchar** standard_untranslated, int standard_untranslated_length1) {
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	GtkListStore* _tmp10_ = NULL;
	GtkTreeIter _tmp11_ = {0};
	GtkListStore* _tmp12_ = NULL;
	GtkTreeIter _tmp13_ = {0};
	const gchar* _tmp14_ = NULL;
	ContactsTypeSetData* _tmp15_ = NULL;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = standard_untranslated;
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0__length1 = standard_untranslated_length1;
#line 612 "contacts-types.c"
	{
		gchar** untranslated_collection = NULL;
		gint untranslated_collection_length1 = 0;
		gint _untranslated_collection_size_ = 0;
		gint untranslated_it = 0;
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		untranslated_collection = _tmp0_;
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		untranslated_collection_length1 = _tmp0__length1;
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		for (untranslated_it = 0; untranslated_it < _tmp0__length1; untranslated_it = untranslated_it + 1) {
#line 624 "contacts-types.c"
			gchar* _tmp1_ = NULL;
			gchar* untranslated = NULL;
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp1_ = g_strdup (untranslated_collection[untranslated_it]);
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			untranslated = _tmp1_;
#line 631 "contacts-types.c"
			{
				ContactsTypeSetData* data = NULL;
				GHashTable* _tmp2_ = NULL;
				const gchar* _tmp3_ = NULL;
				const gchar* _tmp4_ = NULL;
				gconstpointer _tmp5_ = NULL;
				ContactsTypeSetData* _tmp6_ = NULL;
				ContactsTypeSetData* _tmp7_ = NULL;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp2_ = self->priv->display_name_hash;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp3_ = untranslated;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp4_ = g_dgettext (GETTEXT_PACKAGE, _tmp3_);
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp5_ = g_hash_table_lookup (_tmp2_, _tmp4_);
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp6_ = _g_object_ref0 ((ContactsTypeSetData*) _tmp5_);
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				data = _tmp6_;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp7_ = data;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				if (_tmp7_ != NULL) {
#line 656 "contacts-types.c"
					ContactsTypeSetData* _tmp8_ = NULL;
#line 107 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp8_ = data;
#line 107 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					contacts_typeset_add_data_to_store (self, _tmp8_, FALSE);
#line 662 "contacts-types.c"
				} else {
					const gchar* _tmp9_ = NULL;
#line 109 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp9_ = untranslated;
#line 109 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					g_error ("contacts-types.vala:109: Internal error: Can't find display name %s in" \
" TypeSet data", _tmp9_);
#line 669 "contacts-types.c"
				}
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_g_object_unref0 (data);
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_g_free0 (untranslated);
#line 675 "contacts-types.c"
			}
		}
	}
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp10_ = self->store;
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_list_store_append (_tmp10_, &_tmp11_);
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->other_iter = _tmp11_;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp12_ = self->store;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp13_ = self->priv->other_iter;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp14_ = _ ("Other");
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp15_ = contacts_typeset_other_dummy;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_list_store_set (_tmp12_, &_tmp13_, 0, _tmp14_, 1, _tmp15_, -1);
#line 695 "contacts-types.c"
}


static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self) {
	GtkTreeIter* dup;
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	dup = g_new0 (GtkTreeIter, 1);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	memcpy (dup, self, sizeof (GtkTreeIter));
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return dup;
#line 707 "contacts-types.c"
}


static gpointer __gtk_tree_iter_dup0 (gpointer self) {
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return self ? _gtk_tree_iter_dup (self) : NULL;
#line 714 "contacts-types.c"
}


void contacts_typeset_add_custom_label (ContactsTypeSet* self, const gchar* label, GtkTreeIter* iter) {
	GtkTreeIter _vala_iter = {0};
	ContactsTypeSetData* data = NULL;
	GHashTable* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gconstpointer _tmp2_ = NULL;
	ContactsTypeSetData* _tmp3_ = NULL;
	ContactsTypeSetData* _tmp4_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GtkTreeIter* iterp = NULL;
	GHashTable* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gconstpointer _tmp13_ = NULL;
	GtkTreeIter* _tmp14_ = NULL;
	GtkListStore* _tmp16_ = NULL;
	GtkTreeIter _tmp17_ = {0};
	GtkTreeIter _tmp18_ = {0};
	GtkListStore* _tmp19_ = NULL;
	GtkTreeIter _tmp20_ = {0};
	const gchar* _tmp21_ = NULL;
	GHashTable* _tmp22_ = NULL;
	const gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	GtkTreeIter _tmp25_ = {0};
	GtkTreeIter* _tmp26_ = NULL;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (label != NULL);
#line 120 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = self->priv->display_name_hash;
#line 120 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = label;
#line 120 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = g_hash_table_lookup (_tmp0_, _tmp1_);
#line 120 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = _g_object_ref0 ((ContactsTypeSetData*) _tmp2_);
#line 120 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	data = _tmp3_;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = data;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp4_ != NULL) {
#line 762 "contacts-types.c"
		ContactsTypeSetData* _tmp5_ = NULL;
		ContactsTypeSetData* _tmp6_ = NULL;
		GtkTreeIter _tmp7_ = {0};
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = data;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset_add_data_to_store (self, _tmp5_, TRUE);
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp6_ = data;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp7_ = _tmp6_->iter;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_vala_iter = _tmp7_;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (data);
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		if (iter) {
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			*iter = _vala_iter;
#line 782 "contacts-types.c"
		}
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return;
#line 786 "contacts-types.c"
	}
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp8_ = label;
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp9_ = _ ("Other");
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (g_strcmp0 (_tmp8_, _tmp9_) == 0) {
#line 794 "contacts-types.c"
		GtkTreeIter _tmp10_ = {0};
#line 128 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp10_ = self->priv->other_iter;
#line 128 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_vala_iter = _tmp10_;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (data);
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		if (iter) {
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			*iter = _vala_iter;
#line 806 "contacts-types.c"
		}
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return;
#line 810 "contacts-types.c"
	}
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp11_ = self->priv->custom_hash;
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp12_ = label;
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp13_ = g_hash_table_lookup (_tmp11_, _tmp12_);
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	iterp = (GtkTreeIter*) _tmp13_;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp14_ = iterp;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp14_ != NULL) {
#line 824 "contacts-types.c"
		GtkTreeIter* _tmp15_ = NULL;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp15_ = iterp;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_vala_iter = *_tmp15_;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (data);
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		if (iter) {
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			*iter = _vala_iter;
#line 836 "contacts-types.c"
		}
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return;
#line 840 "contacts-types.c"
	}
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp16_ = self->store;
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp17_ = self->priv->custom_iter;
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_list_store_insert_before (_tmp16_, &_tmp18_, &_tmp17_);
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_vala_iter = _tmp18_;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp19_ = self->store;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp20_ = _vala_iter;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp21_ = label;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_list_store_set (_tmp19_, &_tmp20_, 0, _tmp21_, 1, NULL, -1);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp22_ = self->priv->custom_hash;
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp23_ = label;
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp24_ = g_strdup (_tmp23_);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp25_ = _vala_iter;
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp26_ = __gtk_tree_iter_dup0 (&_tmp25_);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_hash_table_insert (_tmp22_, _tmp24_, _tmp26_);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (data);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (iter) {
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		*iter = _vala_iter;
#line 876 "contacts-types.c"
	}
}


static ContactsTypeSetData* contacts_typeset_lookup_data_by_string (ContactsTypeSet* self, const gchar* str) {
	ContactsTypeSetData* result = NULL;
	GList* l = NULL;
	GHashTable* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gconstpointer _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (str != NULL, NULL);
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = self->priv->vcard_lookup_hash;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = str;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = g_hash_table_lookup (_tmp0_, _tmp1_);
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	l = (GList*) _tmp2_;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = l;
#line 902 "contacts-types.c"
	{
		GList* d_collection = NULL;
		GList* d_it = NULL;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		d_collection = _tmp3_;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		for (d_it = d_collection; d_it != NULL; d_it = d_it->next) {
#line 910 "contacts-types.c"
			ContactsTypeSetInitData* d = NULL;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			d = d_it->data;
#line 914 "contacts-types.c"
			{
				ContactsTypeSetInitData* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp4_ = d;
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp5_ = (*_tmp4_).types[1];
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				if (_tmp5_ == NULL) {
#line 924 "contacts-types.c"
					const gchar* dn = NULL;
					ContactsTypeSetInitData* _tmp6_ = NULL;
					const gchar* _tmp7_ = NULL;
					const gchar* _tmp8_ = NULL;
					GHashTable* _tmp9_ = NULL;
					const gchar* _tmp10_ = NULL;
					gconstpointer _tmp11_ = NULL;
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp6_ = d;
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp7_ = (*_tmp6_).display_name_u;
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp8_ = g_dgettext (GETTEXT_PACKAGE, _tmp7_);
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					dn = _tmp8_;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp9_ = self->priv->display_name_hash;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp10_ = dn;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp11_ = g_hash_table_lookup (_tmp9_, _tmp10_);
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					result = (ContactsTypeSetData*) _tmp11_;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					return result;
#line 950 "contacts-types.c"
				}
			}
		}
	}
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = NULL;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 959 "contacts-types.c"
}


static ContactsTypeSetData* contacts_typeset_lookup_data (ContactsTypeSet* self, FolksAbstractFieldDetails* detail) {
	ContactsTypeSetData* result = NULL;
	GeeCollection* i = NULL;
	FolksAbstractFieldDetails* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GeeCollection* _tmp3_ = NULL;
	GeeArrayList* list = NULL;
	GeeArrayList* _tmp7_ = NULL;
	GList* l = NULL;
	GHashTable* _tmp21_ = NULL;
	GeeArrayList* _tmp22_ = NULL;
	gpointer _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	gconstpointer _tmp25_ = NULL;
	GList* _tmp26_ = NULL;
	GList* _tmp27_ = NULL;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (detail != NULL, NULL);
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = detail;
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = folks_abstract_field_details_get_parameter_values (_tmp0_, "type");
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	i = _tmp1_;
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = i;
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp3_ == NULL) {
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp2_ = TRUE;
#line 996 "contacts-types.c"
	} else {
		GeeCollection* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gboolean _tmp6_ = FALSE;
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp4_ = i;
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = gee_collection_get_is_empty (_tmp4_);
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp6_ = _tmp5_;
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp2_ = _tmp6_;
#line 1009 "contacts-types.c"
	}
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp2_) {
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		result = NULL;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (i);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return result;
#line 1019 "contacts-types.c"
	}
#line 161 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp7_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL);
#line 161 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	list = _tmp7_;
#line 1025 "contacts-types.c"
	{
		GeeIterator* _s_it = NULL;
		FolksAbstractFieldDetails* _tmp8_ = NULL;
		GeeCollection* _tmp9_ = NULL;
		GeeCollection* _tmp10_ = NULL;
		GeeIterator* _tmp11_ = NULL;
		GeeIterator* _tmp12_ = NULL;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp8_ = detail;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_ = folks_abstract_field_details_get_parameter_values (_tmp8_, "type");
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp10_ = _tmp9_;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp11_ = gee_iterable_iterator ((GeeIterable*) _tmp10_);
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp12_ = _tmp11_;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (_tmp10_);
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_s_it = _tmp12_;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		while (TRUE) {
#line 1049 "contacts-types.c"
			GeeIterator* _tmp13_ = NULL;
			gboolean _tmp14_ = FALSE;
			gchar* s = NULL;
			GeeIterator* _tmp15_ = NULL;
			gpointer _tmp16_ = NULL;
			GeeArrayList* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp13_ = _s_it;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp14_ = gee_iterator_next (_tmp13_);
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			if (!_tmp14_) {
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				break;
#line 1067 "contacts-types.c"
			}
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp15_ = _s_it;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp16_ = gee_iterator_get (_tmp15_);
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			s = (gchar*) _tmp16_;
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp17_ = list;
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp18_ = s;
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp19_ = g_utf8_strup (_tmp18_, (gssize) -1);
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp20_ = _tmp19_;
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp17_, _tmp20_);
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_g_free0 (_tmp20_);
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_g_free0 (s);
#line 1089 "contacts-types.c"
		}
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (_s_it);
#line 1093 "contacts-types.c"
	}
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp21_ = self->priv->vcard_lookup_hash;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp22_ = list;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp23_ = gee_abstract_list_get ((GeeAbstractList*) _tmp22_, 0);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp24_ = (gchar*) _tmp23_;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp25_ = g_hash_table_lookup (_tmp21_, _tmp24_);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp26_ = (GList*) _tmp25_;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_free0 (_tmp24_);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	l = _tmp26_;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp27_ = l;
#line 1113 "contacts-types.c"
	{
		GList* d_collection = NULL;
		GList* d_it = NULL;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		d_collection = _tmp27_;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		for (d_it = d_collection; d_it != NULL; d_it = d_it->next) {
#line 1121 "contacts-types.c"
			ContactsTypeSetInitData* d = NULL;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			d = d_it->data;
#line 1125 "contacts-types.c"
			{
				gboolean all_found = FALSE;
				gboolean _tmp40_ = FALSE;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				all_found = TRUE;
#line 1131 "contacts-types.c"
				{
					gint j = 0;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					j = 0;
#line 1136 "contacts-types.c"
					{
						gboolean _tmp28_ = FALSE;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp28_ = TRUE;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						while (TRUE) {
#line 1143 "contacts-types.c"
							gboolean _tmp30_ = FALSE;
							gint _tmp31_ = 0;
							GeeArrayList* _tmp35_ = NULL;
							ContactsTypeSetInitData* _tmp36_ = NULL;
							gint _tmp37_ = 0;
							const gchar* _tmp38_ = NULL;
							gboolean _tmp39_ = FALSE;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							if (!_tmp28_) {
#line 1153 "contacts-types.c"
								gint _tmp29_ = 0;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								_tmp29_ = j;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								j = _tmp29_ + 1;
#line 1159 "contacts-types.c"
							}
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp28_ = FALSE;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp31_ = j;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							if (_tmp31_ < CONTACTS_TYPESET_MAX_TYPES) {
#line 1167 "contacts-types.c"
								ContactsTypeSetInitData* _tmp32_ = NULL;
								gint _tmp33_ = 0;
								const gchar* _tmp34_ = NULL;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								_tmp32_ = d;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								_tmp33_ = j;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								_tmp34_ = (*_tmp32_).types[_tmp33_];
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								_tmp30_ = _tmp34_ != NULL;
#line 1179 "contacts-types.c"
							} else {
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								_tmp30_ = FALSE;
#line 1183 "contacts-types.c"
							}
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							if (!_tmp30_) {
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								break;
#line 1189 "contacts-types.c"
							}
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp35_ = list;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp36_ = d;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp37_ = j;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp38_ = (*_tmp36_).types[_tmp37_];
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp39_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp35_, _tmp38_);
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							if (!_tmp39_) {
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								all_found = FALSE;
#line 175 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
								break;
#line 1207 "contacts-types.c"
							}
						}
					}
				}
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp40_ = all_found;
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				if (_tmp40_) {
#line 1216 "contacts-types.c"
					const gchar* dn = NULL;
					ContactsTypeSetInitData* _tmp41_ = NULL;
					const gchar* _tmp42_ = NULL;
					const gchar* _tmp43_ = NULL;
					GHashTable* _tmp44_ = NULL;
					const gchar* _tmp45_ = NULL;
					gconstpointer _tmp46_ = NULL;
#line 179 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp41_ = d;
#line 179 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp42_ = (*_tmp41_).display_name_u;
#line 179 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp43_ = g_dgettext (GETTEXT_PACKAGE, _tmp42_);
#line 179 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					dn = _tmp43_;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp44_ = self->priv->display_name_hash;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp45_ = dn;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp46_ = g_hash_table_lookup (_tmp44_, _tmp45_);
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					result = (ContactsTypeSetData*) _tmp46_;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_g_object_unref0 (list);
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_g_object_unref0 (i);
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					return result;
#line 1246 "contacts-types.c"
				}
			}
		}
	}
#line 184 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = NULL;
#line 184 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (list);
#line 184 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (i);
#line 184 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 1259 "contacts-types.c"
}


void contacts_typeset_lookup_type (ContactsTypeSet* self, FolksAbstractFieldDetails* detail, GtkTreeIter* iter) {
	GtkTreeIter _vala_iter = {0};
	FolksAbstractFieldDetails* _tmp0_ = NULL;
	GeeMultiMap* _tmp1_ = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	ContactsTypeSetData* d = NULL;
	FolksAbstractFieldDetails* _tmp13_ = NULL;
	ContactsTypeSetData* _tmp14_ = NULL;
	ContactsTypeSetData* _tmp15_ = NULL;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (detail != NULL);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = detail;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = folks_abstract_field_details_get_parameters (_tmp0_);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = _tmp1_;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = gee_multi_map_contains (_tmp2_, CONTACTS_TYPESET_X_GOOGLE_LABEL);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp3_) {
#line 1287 "contacts-types.c"
		gchar* label = NULL;
		FolksAbstractFieldDetails* _tmp4_ = NULL;
		GeeMultiMap* _tmp5_ = NULL;
		GeeMultiMap* _tmp6_ = NULL;
		GeeCollection* _tmp7_ = NULL;
		GeeCollection* _tmp8_ = NULL;
		gpointer _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		GtkTreeIter _tmp12_ = {0};
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp4_ = detail;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = folks_abstract_field_details_get_parameters (_tmp4_);
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp6_ = _tmp5_;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp7_ = gee_multi_map_get (_tmp6_, CONTACTS_TYPESET_X_GOOGLE_LABEL);
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp8_ = _tmp7_;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_ = contacts_utils_get_first (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp8_);
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp10_ = (gchar*) _tmp9_;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (_tmp8_);
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		label = _tmp10_;
#line 191 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp11_ = label;
#line 191 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset_add_custom_label (self, _tmp11_, &_tmp12_);
#line 191 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_vala_iter = _tmp12_;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_free0 (label);
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		if (iter) {
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			*iter = _vala_iter;
#line 1328 "contacts-types.c"
		}
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return;
#line 1332 "contacts-types.c"
	}
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp13_ = detail;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp14_ = contacts_typeset_lookup_data (self, _tmp13_);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	d = _tmp14_;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp15_ = d;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp15_ != NULL) {
#line 1344 "contacts-types.c"
		ContactsTypeSetData* _tmp16_ = NULL;
		ContactsTypeSetData* _tmp17_ = NULL;
		GtkTreeIter _tmp18_ = {0};
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp16_ = d;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset_add_data_to_store (self, _tmp16_, TRUE);
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp17_ = d;
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp18_ = _tmp17_->iter;
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_vala_iter = _tmp18_;
#line 1358 "contacts-types.c"
	} else {
		GtkTreeIter _tmp19_ = {0};
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp19_ = self->priv->other_iter;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_vala_iter = _tmp19_;
#line 1365 "contacts-types.c"
	}
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (iter) {
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		*iter = _vala_iter;
#line 1371 "contacts-types.c"
	}
}


void contacts_typeset_lookup_type_by_string (ContactsTypeSet* self, const gchar* type, GtkTreeIter* iter) {
	GtkTreeIter _vala_iter = {0};
	ContactsTypeSetData* d = NULL;
	const gchar* _tmp0_ = NULL;
	ContactsTypeSetData* _tmp1_ = NULL;
	ContactsTypeSetData* _tmp2_ = NULL;
#line 204 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 204 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (type != NULL);
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = type;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = contacts_typeset_lookup_data_by_string (self, _tmp0_);
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	d = _tmp1_;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = d;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp2_ != NULL) {
#line 1396 "contacts-types.c"
		ContactsTypeSetData* _tmp3_ = NULL;
		GtkTreeIter _tmp4_ = {0};
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp3_ = d;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp4_ = _tmp3_->iter;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_vala_iter = _tmp4_;
#line 1405 "contacts-types.c"
	} else {
		GtkTreeIter _tmp5_ = {0};
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = self->priv->other_iter;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_vala_iter = _tmp5_;
#line 1412 "contacts-types.c"
	}
#line 204 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (iter) {
#line 204 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		*iter = _vala_iter;
#line 1418 "contacts-types.c"
	}
}


void contacts_typeset_type_seen (ContactsTypeSet* self, FolksAbstractFieldDetails* detail) {
	FolksAbstractFieldDetails* _tmp0_ = NULL;
#line 214 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 214 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (detail != NULL);
#line 215 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = detail;
#line 215 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typeset_lookup_type (self, _tmp0_, NULL);
#line 1433 "contacts-types.c"
}


gchar* contacts_typeset_format_type (ContactsTypeSet* self, FolksAbstractFieldDetails* detail) {
	gchar* result = NULL;
	FolksAbstractFieldDetails* _tmp0_ = NULL;
	GeeMultiMap* _tmp1_ = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	ContactsTypeSetData* d = NULL;
	FolksAbstractFieldDetails* _tmp11_ = NULL;
	ContactsTypeSetData* _tmp12_ = NULL;
	ContactsTypeSetData* _tmp13_ = NULL;
	const gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (detail != NULL, NULL);
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = detail;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = folks_abstract_field_details_get_parameters (_tmp0_);
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = _tmp1_;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = gee_multi_map_contains (_tmp2_, CONTACTS_TYPESET_X_GOOGLE_LABEL);
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp3_) {
#line 1463 "contacts-types.c"
		FolksAbstractFieldDetails* _tmp4_ = NULL;
		GeeMultiMap* _tmp5_ = NULL;
		GeeMultiMap* _tmp6_ = NULL;
		GeeCollection* _tmp7_ = NULL;
		GeeCollection* _tmp8_ = NULL;
		gpointer _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp4_ = detail;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = folks_abstract_field_details_get_parameters (_tmp4_);
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp6_ = _tmp5_;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp7_ = gee_multi_map_get (_tmp6_, CONTACTS_TYPESET_X_GOOGLE_LABEL);
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp8_ = _tmp7_;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_ = contacts_utils_get_first (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp8_);
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp10_ = (gchar*) _tmp9_;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (_tmp8_);
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		result = _tmp10_;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return result;
#line 1491 "contacts-types.c"
	}
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp11_ = detail;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp12_ = contacts_typeset_lookup_data (self, _tmp11_);
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	d = _tmp12_;
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp13_ = d;
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp13_ != NULL) {
#line 1503 "contacts-types.c"
		ContactsTypeSetData* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp14_ = d;
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp15_ = _tmp14_->display_name;
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp16_ = g_strdup (_tmp15_);
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		result = _tmp16_;
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return result;
#line 1517 "contacts-types.c"
	}
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp17_ = _ ("Other");
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp18_ = g_strdup (_tmp17_);
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = _tmp18_;
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 1527 "contacts-types.c"
}


void contacts_typeset_update_details (ContactsTypeSet* self, FolksAbstractFieldDetails* details, GtkTreeIter* iter) {
	GeeMultiMap* old_parameters = NULL;
	FolksAbstractFieldDetails* _tmp0_ = NULL;
	GeeMultiMap* _tmp1_ = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeMultiMap* _tmp3_ = NULL;
	FolksAbstractFieldDetails* _tmp4_ = NULL;
	GeeHashMultiMap* _tmp5_ = NULL;
	GeeHashMultiMap* _tmp6_ = NULL;
	gboolean has_pref = FALSE;
	ContactsTypeSetData* data = NULL;
	gchar* display_name = NULL;
	GtkListStore* _tmp45_ = NULL;
	GtkTreeIter _tmp46_ = {0};
	const gchar* _tmp47_ = NULL;
	ContactsTypeSetData* _tmp48_ = NULL;
	ContactsTypeSetData* _tmp49_ = NULL;
	ContactsTypeSetData* _tmp50_ = NULL;
	gboolean _tmp79_ = FALSE;
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (details != NULL);
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (iter != NULL);
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = details;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = folks_abstract_field_details_get_parameters (_tmp0_);
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = _tmp1_;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	old_parameters = _tmp3_;
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = details;
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp5_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp6_ = _tmp5_;
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	folks_abstract_field_details_set_parameters (_tmp4_, (GeeMultiMap*) _tmp6_);
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (_tmp6_);
#line 234 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	has_pref = FALSE;
#line 1578 "contacts-types.c"
	{
		GeeIterator* _value_it = NULL;
		GeeMultiMap* _tmp7_ = NULL;
		GeeCollection* _tmp8_ = NULL;
		GeeCollection* _tmp9_ = NULL;
		GeeIterator* _tmp10_ = NULL;
		GeeIterator* _tmp11_ = NULL;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp7_ = old_parameters;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp8_ = gee_multi_map_get (_tmp7_, "type");
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_ = _tmp8_;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp10_ = gee_iterable_iterator ((GeeIterable*) _tmp9_);
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp11_ = _tmp10_;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (_tmp9_);
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_value_it = _tmp11_;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		while (TRUE) {
#line 1602 "contacts-types.c"
			GeeIterator* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			gchar* value = NULL;
			GeeIterator* _tmp14_ = NULL;
			gpointer _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			gint _tmp17_ = 0;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp12_ = _value_it;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp13_ = gee_iterator_next (_tmp12_);
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			if (!_tmp13_) {
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				break;
#line 1618 "contacts-types.c"
			}
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp14_ = _value_it;
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp15_ = gee_iterator_get (_tmp14_);
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			value = (gchar*) _tmp15_;
#line 236 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp16_ = value;
#line 236 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp17_ = g_ascii_strcasecmp (_tmp16_, "PREF");
#line 236 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			if (_tmp17_ == 0) {
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				has_pref = TRUE;
#line 238 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_g_free0 (value);
#line 238 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				break;
#line 1638 "contacts-types.c"
			}
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_g_free0 (value);
#line 1642 "contacts-types.c"
		}
#line 235 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (_value_it);
#line 1646 "contacts-types.c"
	}
	{
		GeeIterator* _param_it = NULL;
		GeeMultiMap* _tmp18_ = NULL;
		GeeSet* _tmp19_ = NULL;
		GeeSet* _tmp20_ = NULL;
		GeeIterator* _tmp21_ = NULL;
		GeeIterator* _tmp22_ = NULL;
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp18_ = old_parameters;
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp19_ = gee_multi_map_get_keys (_tmp18_);
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp20_ = _tmp19_;
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp22_ = _tmp21_;
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (_tmp20_);
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_param_it = _tmp22_;
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		while (TRUE) {
#line 1671 "contacts-types.c"
			GeeIterator* _tmp23_ = NULL;
			gboolean _tmp24_ = FALSE;
			gchar* param = NULL;
			GeeIterator* _tmp25_ = NULL;
			gpointer _tmp26_ = NULL;
			gboolean _tmp27_ = FALSE;
			const gchar* _tmp28_ = NULL;
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp23_ = _param_it;
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			if (!_tmp24_) {
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				break;
#line 1687 "contacts-types.c"
			}
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp25_ = _param_it;
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			param = (gchar*) _tmp26_;
#line 242 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp28_ = param;
#line 242 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			if (g_strcmp0 (_tmp28_, "type") != 0) {
#line 1699 "contacts-types.c"
				const gchar* _tmp29_ = NULL;
#line 242 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp29_ = param;
#line 242 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp27_ = g_strcmp0 (_tmp29_, CONTACTS_TYPESET_X_GOOGLE_LABEL) != 0;
#line 1705 "contacts-types.c"
			} else {
#line 242 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp27_ = FALSE;
#line 1709 "contacts-types.c"
			}
#line 242 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			if (_tmp27_) {
#line 1713 "contacts-types.c"
				{
					GeeIterator* _value_it = NULL;
					GeeMultiMap* _tmp30_ = NULL;
					const gchar* _tmp31_ = NULL;
					GeeCollection* _tmp32_ = NULL;
					GeeCollection* _tmp33_ = NULL;
					GeeIterator* _tmp34_ = NULL;
					GeeIterator* _tmp35_ = NULL;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp30_ = old_parameters;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp31_ = param;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp32_ = gee_multi_map_get (_tmp30_, _tmp31_);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp33_ = _tmp32_;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp34_ = gee_iterable_iterator ((GeeIterable*) _tmp33_);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp35_ = _tmp34_;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_g_object_unref0 (_tmp33_);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_value_it = _tmp35_;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					while (TRUE) {
#line 1740 "contacts-types.c"
						GeeIterator* _tmp36_ = NULL;
						gboolean _tmp37_ = FALSE;
						gchar* value = NULL;
						GeeIterator* _tmp38_ = NULL;
						gpointer _tmp39_ = NULL;
						FolksAbstractFieldDetails* _tmp40_ = NULL;
						GeeMultiMap* _tmp41_ = NULL;
						GeeMultiMap* _tmp42_ = NULL;
						const gchar* _tmp43_ = NULL;
						const gchar* _tmp44_ = NULL;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp36_ = _value_it;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp37_ = gee_iterator_next (_tmp36_);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						if (!_tmp37_) {
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							break;
#line 1759 "contacts-types.c"
						}
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp38_ = _value_it;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp39_ = gee_iterator_get (_tmp38_);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						value = (gchar*) _tmp39_;
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp40_ = details;
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp41_ = folks_abstract_field_details_get_parameters (_tmp40_);
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp42_ = _tmp41_;
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp43_ = param;
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp44_ = value;
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						gee_multi_map_set (_tmp42_, _tmp43_, _tmp44_);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_g_free0 (value);
#line 1781 "contacts-types.c"
					}
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_g_object_unref0 (_value_it);
#line 1785 "contacts-types.c"
				}
			}
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_g_free0 (param);
#line 1790 "contacts-types.c"
		}
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (_param_it);
#line 1794 "contacts-types.c"
	}
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp45_ = self->store;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp46_ = *iter;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp45_, &_tmp46_, 0, &display_name, 1, &data, -1);
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp47_ = display_name;
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_vala_assert (_tmp47_ != NULL, "display_name != null");
#line 254 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp48_ = data;
#line 254 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp49_ = contacts_typeset_custom_dummy;
#line 254 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_vala_assert (_tmp48_ != _tmp49_, "data != custom_dummy");
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp50_ = data;
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp50_ == NULL) {
#line 1816 "contacts-types.c"
		FolksAbstractFieldDetails* _tmp51_ = NULL;
		GeeMultiMap* _tmp52_ = NULL;
		GeeMultiMap* _tmp53_ = NULL;
		FolksAbstractFieldDetails* _tmp54_ = NULL;
		GeeMultiMap* _tmp55_ = NULL;
		GeeMultiMap* _tmp56_ = NULL;
		const gchar* _tmp57_ = NULL;
#line 257 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp51_ = details;
#line 257 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp52_ = folks_abstract_field_details_get_parameters (_tmp51_);
#line 257 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp53_ = _tmp52_;
#line 257 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		gee_multi_map_set (_tmp53_, "type", "OTHER");
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp54_ = details;
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp55_ = folks_abstract_field_details_get_parameters (_tmp54_);
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp56_ = _tmp55_;
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp57_ = display_name;
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		gee_multi_map_set (_tmp56_, CONTACTS_TYPESET_X_GOOGLE_LABEL, _tmp57_);
#line 1842 "contacts-types.c"
	} else {
		ContactsTypeSetData* _tmp58_ = NULL;
		ContactsTypeSetData* _tmp59_ = NULL;
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp58_ = data;
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp59_ = contacts_typeset_other_dummy;
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		if (_tmp58_ == _tmp59_) {
#line 1852 "contacts-types.c"
			FolksAbstractFieldDetails* _tmp60_ = NULL;
			GeeMultiMap* _tmp61_ = NULL;
			GeeMultiMap* _tmp62_ = NULL;
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp60_ = details;
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp61_ = folks_abstract_field_details_get_parameters (_tmp60_);
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp62_ = _tmp61_;
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			gee_multi_map_set (_tmp62_, "type", "OTHER");
#line 1864 "contacts-types.c"
		} else {
			ContactsTypeSetInitData* init_data = NULL;
			ContactsTypeSetData* _tmp63_ = NULL;
			GList* _tmp64_ = NULL;
			gconstpointer _tmp65_ = NULL;
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp63_ = data;
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp64_ = _tmp63_->init_data;
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp65_ = _tmp64_->data;
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			init_data = _tmp65_;
#line 1878 "contacts-types.c"
			{
				gint j = 0;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				j = 0;
#line 1883 "contacts-types.c"
				{
					gboolean _tmp66_ = FALSE;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp66_ = TRUE;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					while (TRUE) {
#line 1890 "contacts-types.c"
						gboolean _tmp68_ = FALSE;
						gint _tmp69_ = 0;
						FolksAbstractFieldDetails* _tmp73_ = NULL;
						GeeMultiMap* _tmp74_ = NULL;
						GeeMultiMap* _tmp75_ = NULL;
						ContactsTypeSetInitData* _tmp76_ = NULL;
						gint _tmp77_ = 0;
						const gchar* _tmp78_ = NULL;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						if (!_tmp66_) {
#line 1901 "contacts-types.c"
							gint _tmp67_ = 0;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp67_ = j;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							j = _tmp67_ + 1;
#line 1907 "contacts-types.c"
						}
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp66_ = FALSE;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp69_ = j;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						if (_tmp69_ < CONTACTS_TYPESET_MAX_TYPES) {
#line 1915 "contacts-types.c"
							ContactsTypeSetInitData* _tmp70_ = NULL;
							gint _tmp71_ = 0;
							const gchar* _tmp72_ = NULL;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp70_ = init_data;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp71_ = j;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp72_ = (*_tmp70_).types[_tmp71_];
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp68_ = _tmp72_ != NULL;
#line 1927 "contacts-types.c"
						} else {
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							_tmp68_ = FALSE;
#line 1931 "contacts-types.c"
						}
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						if (!_tmp68_) {
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
							break;
#line 1937 "contacts-types.c"
						}
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp73_ = details;
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp74_ = folks_abstract_field_details_get_parameters (_tmp73_);
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp75_ = _tmp74_;
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp76_ = init_data;
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp77_ = j;
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp78_ = (*_tmp76_).types[_tmp77_];
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						gee_multi_map_set (_tmp75_, "type", _tmp78_);
#line 1953 "contacts-types.c"
					}
				}
			}
		}
	}
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp79_ = has_pref;
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp79_) {
#line 1963 "contacts-types.c"
		FolksAbstractFieldDetails* _tmp80_ = NULL;
		GeeMultiMap* _tmp81_ = NULL;
		GeeMultiMap* _tmp82_ = NULL;
#line 271 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp80_ = details;
#line 271 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp81_ = folks_abstract_field_details_get_parameters (_tmp80_);
#line 271 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp82_ = _tmp81_;
#line 271 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		gee_multi_map_set (_tmp82_, "type", "PREF");
#line 1975 "contacts-types.c"
	}
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_free0 (display_name);
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (data);
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (old_parameters);
#line 1983 "contacts-types.c"
}


gboolean contacts_typeset_is_custom (ContactsTypeSet* self, GtkTreeIter* iter) {
	gboolean result = FALSE;
	ContactsTypeSetData* data = NULL;
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	ContactsTypeSetData* _tmp2_ = NULL;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 276 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = self->store;
#line 276 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = *iter;
#line 276 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, 1, &data, -1);
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = contacts_typeset_custom_dummy;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = data == _tmp2_;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (data);
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2011 "contacts-types.c"
}


ContactsTypeSet* contacts_typeset_get_general (void) {
	ContactsTypeSet* result;
	gchar** standard = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gint standard_length1 = 0;
	gint _standard_size_ = 0;
	ContactsTypeSet* _tmp3_ = NULL;
	ContactsTypeSet* _tmp12_ = NULL;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = g_strdup ("Work");
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = g_strdup ("Home");
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_[0] = _tmp0_;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_[1] = _tmp1_;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard = _tmp2_;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard_length1 = 2;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_standard_size_ = standard_length1;
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = contacts_typeset__general;
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp3_ == NULL) {
#line 2045 "contacts-types.c"
		ContactsTypeSet* _tmp4_ = NULL;
		ContactsTypeSet* _tmp10_ = NULL;
		gchar** _tmp11_ = NULL;
		gint _tmp11__length1 = 0;
#line 293 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp4_ = contacts_typeset_new ();
#line 293 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (contacts_typeset__general);
#line 293 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset__general = _tmp4_;
#line 2056 "contacts-types.c"
		{
			gint i = 0;
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			i = 0;
#line 2061 "contacts-types.c"
			{
				gboolean _tmp5_ = FALSE;
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp5_ = TRUE;
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				while (TRUE) {
#line 2068 "contacts-types.c"
					gint _tmp7_ = 0;
					ContactsTypeSet* _tmp8_ = NULL;
					gint _tmp9_ = 0;
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					if (!_tmp5_) {
#line 2074 "contacts-types.c"
						gint _tmp6_ = 0;
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp6_ = i;
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						i = _tmp6_ + 1;
#line 2080 "contacts-types.c"
					}
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp5_ = FALSE;
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp7_ = i;
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					if (!(_tmp7_ < G_N_ELEMENTS (CONTACTS_TYPESET_general_data))) {
#line 294 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						break;
#line 2090 "contacts-types.c"
					}
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp8_ = contacts_typeset__general;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp9_ = i;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					contacts_typeset_add_init_data (_tmp8_, &CONTACTS_TYPESET_general_data[_tmp9_]);
#line 2098 "contacts-types.c"
				}
			}
		}
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp10_ = contacts_typeset__general;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp11_ = standard;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp11__length1 = standard_length1;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset_add_init_data_done (_tmp10_, _tmp11_, _tmp11__length1);
#line 2110 "contacts-types.c"
	}
#line 299 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp12_ = contacts_typeset__general;
#line 299 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = _tmp12_;
#line 299 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard = (_vala_array_free (standard, standard_length1, (GDestroyNotify) g_free), NULL);
#line 299 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2120 "contacts-types.c"
}


ContactsTypeSet* contacts_typeset_get_email (void) {
	ContactsTypeSet* result;
	gchar** standard = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint standard_length1 = 0;
	gint _standard_size_ = 0;
	ContactsTypeSet* _tmp4_ = NULL;
	ContactsTypeSet* _tmp13_ = NULL;
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = g_strdup ("Personal");
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = g_strdup ("Home");
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = g_strdup ("Work");
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = g_new0 (gchar*, 3 + 1);
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_[0] = _tmp0_;
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_[1] = _tmp1_;
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_[2] = _tmp2_;
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard = _tmp3_;
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard_length1 = 3;
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_standard_size_ = standard_length1;
#line 316 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = contacts_typeset__email;
#line 316 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp4_ == NULL) {
#line 2159 "contacts-types.c"
		ContactsTypeSet* _tmp5_ = NULL;
		ContactsTypeSet* _tmp11_ = NULL;
		gchar** _tmp12_ = NULL;
		gint _tmp12__length1 = 0;
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = contacts_typeset_new ();
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (contacts_typeset__email);
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset__email = _tmp5_;
#line 2170 "contacts-types.c"
		{
			gint i = 0;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			i = 0;
#line 2175 "contacts-types.c"
			{
				gboolean _tmp6_ = FALSE;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp6_ = TRUE;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				while (TRUE) {
#line 2182 "contacts-types.c"
					gint _tmp8_ = 0;
					ContactsTypeSet* _tmp9_ = NULL;
					gint _tmp10_ = 0;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					if (!_tmp6_) {
#line 2188 "contacts-types.c"
						gint _tmp7_ = 0;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp7_ = i;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						i = _tmp7_ + 1;
#line 2194 "contacts-types.c"
					}
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp6_ = FALSE;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp8_ = i;
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					if (!(_tmp8_ < G_N_ELEMENTS (CONTACTS_TYPESET_email_data))) {
#line 318 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						break;
#line 2204 "contacts-types.c"
					}
#line 319 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp9_ = contacts_typeset__email;
#line 319 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp10_ = i;
#line 319 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					contacts_typeset_add_init_data (_tmp9_, &CONTACTS_TYPESET_email_data[_tmp10_]);
#line 2212 "contacts-types.c"
				}
			}
		}
#line 320 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp11_ = contacts_typeset__email;
#line 320 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp12_ = standard;
#line 320 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp12__length1 = standard_length1;
#line 320 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset_add_init_data_done (_tmp11_, _tmp12_, _tmp12__length1);
#line 2224 "contacts-types.c"
	}
#line 323 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp13_ = contacts_typeset__email;
#line 323 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = _tmp13_;
#line 323 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard = (_vala_array_free (standard, standard_length1, (GDestroyNotify) g_free), NULL);
#line 323 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2234 "contacts-types.c"
}


ContactsTypeSet* contacts_typeset_get_phone (void) {
	ContactsTypeSet* result;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	static const ContactsTypeSetInitData data[] = {{"Assistant", {"X-EVOLUTION-ASSISTANT"}, 3}, {"Work", {"WORK", "VOICE"}, 3}, {"Work Fax", {"WORK", "FAX"}, 3}, {"Callback", {"X-EVOLUTION-CALLBACK"}, 3}, {"Car", {"CAR"}, 3}, {"Company", {"X-EVOLUTION-COMPANY"}, 3}, {"Home", {"HOME", "VOICE"}, 3}, {"Home Fax", {"HOME", "FAX"}, 3}, {"ISDN", {"ISDN"}, 3}, {"Mobile", {"CELL"}, 3}, {"Other", {"VOICE"}, 3}, {"Fax", {"FAX"}, 3}, {"Pager", {"PAGER"}, 3}, {"Radio", {"X-EVOLUTION-RADIO"}, 3}, {"Telex", {"X-EVOLUTION-TELEX"}, 3}, {"TTY", {"X-EVOLUTION-TTYTDD"}, 3}};
#line 2242 "contacts-types.c"
	gchar** standard = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint standard_length1 = 0;
	gint _standard_size_ = 0;
	ContactsTypeSet* _tmp4_ = NULL;
	ContactsTypeSet* _tmp18_ = NULL;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = g_strdup ("Mobile");
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = g_strdup ("Work");
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = g_strdup ("Home");
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = g_new0 (gchar*, 3 + 1);
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_[0] = _tmp0_;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_[1] = _tmp1_;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_[2] = _tmp2_;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard = _tmp3_;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard_length1 = 3;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_standard_size_ = standard_length1;
#line 357 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = contacts_typeset__phone;
#line 357 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp4_ == NULL) {
#line 2276 "contacts-types.c"
		ContactsTypeSet* _tmp5_ = NULL;
		ContactsTypeSet* _tmp16_ = NULL;
		gchar** _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
#line 358 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = contacts_typeset_new ();
#line 358 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_g_object_unref0 (contacts_typeset__phone);
#line 358 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset__phone = _tmp5_;
#line 2287 "contacts-types.c"
		{
			gint i = 0;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			i = 0;
#line 2292 "contacts-types.c"
			{
				gboolean _tmp6_ = FALSE;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp6_ = TRUE;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				while (TRUE) {
#line 2299 "contacts-types.c"
					gint _tmp8_ = 0;
					ContactsTypeSet* _tmp9_ = NULL;
					gint _tmp10_ = 0;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					if (!_tmp6_) {
#line 2305 "contacts-types.c"
						gint _tmp7_ = 0;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp7_ = i;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						i = _tmp7_ + 1;
#line 2311 "contacts-types.c"
					}
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp6_ = FALSE;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp8_ = i;
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					if (!(_tmp8_ < G_N_ELEMENTS (data))) {
#line 359 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						break;
#line 2321 "contacts-types.c"
					}
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp9_ = contacts_typeset__phone;
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp10_ = i;
#line 360 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					contacts_typeset_add_init_data (_tmp9_, &data[_tmp10_]);
#line 2329 "contacts-types.c"
				}
			}
		}
		{
			gint i = 0;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			i = 0;
#line 2337 "contacts-types.c"
			{
				gboolean _tmp11_ = FALSE;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				_tmp11_ = TRUE;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
				while (TRUE) {
#line 2344 "contacts-types.c"
					gint _tmp13_ = 0;
					ContactsTypeSet* _tmp14_ = NULL;
					gint _tmp15_ = 0;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					if (!_tmp11_) {
#line 2350 "contacts-types.c"
						gint _tmp12_ = 0;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						_tmp12_ = i;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						i = _tmp12_ + 1;
#line 2356 "contacts-types.c"
					}
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp11_ = FALSE;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp13_ = i;
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					if (!(_tmp13_ < G_N_ELEMENTS (CONTACTS_TYPESET_general_data))) {
#line 361 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
						break;
#line 2366 "contacts-types.c"
					}
#line 362 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp14_ = contacts_typeset__phone;
#line 362 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					_tmp15_ = i;
#line 362 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
					contacts_typeset_add_init_data (_tmp14_, &CONTACTS_TYPESET_general_data[_tmp15_]);
#line 2374 "contacts-types.c"
				}
			}
		}
#line 363 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp16_ = contacts_typeset__phone;
#line 363 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp17_ = standard;
#line 363 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp17__length1 = standard_length1;
#line 363 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset_add_init_data_done (_tmp16_, _tmp17_, _tmp17__length1);
#line 2386 "contacts-types.c"
	}
#line 366 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp18_ = contacts_typeset__phone;
#line 366 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = _tmp18_;
#line 366 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	standard = (_vala_array_free (standard, standard_length1, (GDestroyNotify) g_free), NULL);
#line 366 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2396 "contacts-types.c"
}


static ContactsTypeSetData* contacts_typeset_data_construct (GType object_type) {
	ContactsTypeSetData * self = NULL;
#line 31 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self = (ContactsTypeSetData*) g_object_new (object_type, NULL);
#line 31 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return self;
#line 2406 "contacts-types.c"
}


static ContactsTypeSetData* contacts_typeset_data_new (void) {
#line 31 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return contacts_typeset_data_construct (CONTACTS_TYPESET_TYPE_DATA);
#line 2413 "contacts-types.c"
}


static void contacts_typeset_data_class_init (ContactsTypeSetDataClass * klass) {
#line 31 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typeset_data_parent_class = g_type_class_peek_parent (klass);
#line 31 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	G_OBJECT_CLASS (klass)->finalize = contacts_typeset_data_finalize;
#line 2422 "contacts-types.c"
}


static void contacts_typeset_data_instance_init (ContactsTypeSetData * self) {
}


static void contacts_typeset_data_finalize (GObject* obj) {
	ContactsTypeSetData * self;
#line 31 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CONTACTS_TYPESET_TYPE_DATA, ContactsTypeSetData);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_free0 (self->display_name);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_list_free0 (self->init_data);
#line 31 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	G_OBJECT_CLASS (contacts_typeset_data_parent_class)->finalize (obj);
#line 2440 "contacts-types.c"
}


static GType contacts_typeset_data_get_type (void) {
	static volatile gsize contacts_typeset_data_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_typeset_data_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ContactsTypeSetDataClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) contacts_typeset_data_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ContactsTypeSetData), 0, (GInstanceInitFunc) contacts_typeset_data_instance_init, NULL };
		GType contacts_typeset_data_type_id;
		contacts_typeset_data_type_id = g_type_register_static (G_TYPE_OBJECT, "ContactsTypeSetData", &g_define_type_info, 0);
		g_once_init_leave (&contacts_typeset_data_type_id__volatile, contacts_typeset_data_type_id);
	}
	return contacts_typeset_data_type_id__volatile;
}


static ContactsTypeSetInitData* contacts_typeset_init_data_dup (const ContactsTypeSetInitData* self) {
	ContactsTypeSetInitData* dup;
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	dup = g_new0 (ContactsTypeSetInitData, 1);
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	memcpy (dup, self, sizeof (ContactsTypeSetInitData));
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return dup;
#line 2464 "contacts-types.c"
}


static void contacts_typeset_init_data_free (ContactsTypeSetInitData* self) {
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_free (self);
#line 2471 "contacts-types.c"
}


static GType contacts_typeset_init_data_get_type (void) {
	static volatile gsize contacts_typeset_init_data_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_typeset_init_data_type_id__volatile)) {
		GType contacts_typeset_init_data_type_id;
		contacts_typeset_init_data_type_id = g_boxed_type_register_static ("ContactsTypeSetInitData", (GBoxedCopyFunc) contacts_typeset_init_data_dup, (GBoxedFreeFunc) contacts_typeset_init_data_free);
		g_once_init_leave (&contacts_typeset_init_data_type_id__volatile, contacts_typeset_init_data_type_id);
	}
	return contacts_typeset_init_data_type_id__volatile;
}


static void contacts_typeset_class_init (ContactsTypeSetClass * klass) {
	ContactsTypeSetData* _tmp0_ = NULL;
	ContactsTypeSetData* _tmp1_ = NULL;
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typeset_parent_class = g_type_class_peek_parent (klass);
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_type_class_add_private (klass, sizeof (ContactsTypeSetPrivate));
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_contacts_typeset_get_property;
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	G_OBJECT_CLASS (klass)->finalize = contacts_typeset_finalize;
#line 39 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = contacts_typeset_data_new ();
#line 39 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typeset_custom_dummy = _tmp0_;
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = contacts_typeset_data_new ();
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typeset_other_dummy = _tmp1_;
#line 2505 "contacts-types.c"
}


static void contacts_typeset_instance_init (ContactsTypeSet * self) {
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv = CONTACTS_TYPESET_GET_PRIVATE (self);
#line 2512 "contacts-types.c"
}


static void contacts_typeset_finalize (GObject* obj) {
	ContactsTypeSet * self;
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CONTACTS_TYPE_TYPESET, ContactsTypeSet);
#line 44 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_hash_table_unref0 (self->priv->display_name_hash);
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_hash_table_unref0 (self->priv->vcard_lookup_hash);
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_hash_table_unref0 (self->priv->custom_hash);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (self->store);
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	G_OBJECT_CLASS (contacts_typeset_parent_class)->finalize (obj);
#line 2530 "contacts-types.c"
}


GType contacts_typeset_get_type (void) {
	static volatile gsize contacts_typeset_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_typeset_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ContactsTypeSetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) contacts_typeset_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ContactsTypeSet), 0, (GInstanceInitFunc) contacts_typeset_instance_init, NULL };
		GType contacts_typeset_type_id;
		contacts_typeset_type_id = g_type_register_static (G_TYPE_OBJECT, "ContactsTypeSet", &g_define_type_info, 0);
		g_once_init_leave (&contacts_typeset_type_id__volatile, contacts_typeset_type_id);
	}
	return contacts_typeset_type_id__volatile;
}


static void _vala_contacts_typeset_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ContactsTypeSet * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CONTACTS_TYPE_TYPESET, ContactsTypeSet);
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	switch (property_id) {
#line 2551 "contacts-types.c"
		default:
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		break;
#line 2557 "contacts-types.c"
	}
}


static gboolean __lambda39_ (ContactsTypeCombo* self, GtkTreeModel* model, GtkTreeIter* iter) {
	gboolean result = FALSE;
	gchar* s = NULL;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 396 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = model;
#line 396 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = *iter;
#line 396 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &s, -1);
#line 397 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = s == NULL;
#line 397 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_free0 (s);
#line 397 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2583 "contacts-types.c"
}


static gboolean ___lambda39__gtk_tree_view_row_separator_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda39_ ((ContactsTypeCombo*) self, model, iter);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2592 "contacts-types.c"
}


static void _contacts_typecombo_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 415 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typecombo_combo_changed ((ContactsTypeCombo*) self, _sender);
#line 2599 "contacts-types.c"
}


static gboolean _contacts_typecombo_entry_focus_out_event_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = contacts_typecombo_entry_focus_out_event ((ContactsTypeCombo*) self, event);
#line 416 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2608 "contacts-types.c"
}


static void _contacts_typecombo_entry_activate_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 417 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typecombo_entry_activate ((ContactsTypeCombo*) self);
#line 2615 "contacts-types.c"
}


static gboolean _contacts_typecombo_entry_key_release_gtk_widget_key_release_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = contacts_typecombo_entry_key_release ((ContactsTypeCombo*) self, event);
#line 418 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2624 "contacts-types.c"
}


ContactsTypeCombo* contacts_typecombo_construct (GType object_type, ContactsTypeSet* type_set) {
	ContactsTypeCombo * self = NULL;
	ContactsTypeSet* _tmp0_ = NULL;
	ContactsTypeSet* _tmp1_ = NULL;
	ContactsTypeSet* _tmp2_ = NULL;
	GtkListStore* _tmp3_ = NULL;
	GtkComboBox* _tmp4_ = NULL;
	GtkComboBox* _tmp5_ = NULL;
	GtkComboBox* _tmp6_ = NULL;
	GtkComboBox* _tmp7_ = NULL;
	GtkCellRendererText* renderer = NULL;
	GtkCellRendererText* _tmp8_ = NULL;
	GtkComboBox* _tmp9_ = NULL;
	GtkComboBox* _tmp10_ = NULL;
	GtkComboBox* _tmp11_ = NULL;
	GtkEntry* _tmp12_ = NULL;
	GtkEntry* _tmp13_ = NULL;
	GtkStyleContext* _tmp14_ = NULL;
	GtkEntry* _tmp15_ = NULL;
	GtkEntry* _tmp16_ = NULL;
	GtkEntry* _tmp17_ = NULL;
	GtkEntry* _tmp18_ = NULL;
	GtkComboBox* _tmp19_ = NULL;
	GtkEntry* _tmp20_ = NULL;
	GtkComboBox* _tmp21_ = NULL;
	GtkComboBox* _tmp22_ = NULL;
	GtkEntry* _tmp23_ = NULL;
	GtkEntry* _tmp24_ = NULL;
	GtkEntry* _tmp25_ = NULL;
#line 382 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (type_set != NULL, NULL);
#line 382 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self = (ContactsTypeCombo*) g_object_new (object_type, NULL);
#line 383 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = type_set;
#line 383 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 383 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (self->priv->type_set);
#line 383 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->type_set = _tmp1_;
#line 385 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = type_set;
#line 385 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = _tmp2_->store;
#line 385 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = (GtkComboBox*) gtk_combo_box_new_with_model ((GtkTreeModel*) _tmp3_);
#line 385 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_object_ref_sink (_tmp4_);
#line 385 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (self->priv->combo);
#line 385 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->combo = _tmp4_;
#line 386 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp5_ = self->priv->combo;
#line 386 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp5_, GTK_ALIGN_FILL);
#line 387 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp6_ = self->priv->combo;
#line 387 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp6_, TRUE);
#line 388 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp7_ = self->priv->combo;
#line 388 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp7_);
#line 390 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp8_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 390 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_object_ref_sink (_tmp8_);
#line 390 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	renderer = _tmp8_;
#line 391 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp9_ = self->priv->combo;
#line 391 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_cell_layout_pack_start ((GtkCellLayout*) _tmp9_, (GtkCellRenderer*) renderer, TRUE);
#line 392 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp10_ = self->priv->combo;
#line 392 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_cell_layout_set_attributes ((GtkCellLayout*) _tmp10_, (GtkCellRenderer*) renderer, "text", 0, NULL);
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp11_ = self->priv->combo;
#line 394 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_combo_box_set_row_separator_func (_tmp11_, ___lambda39__gtk_tree_view_row_separator_func, g_object_ref (self), g_object_unref);
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp12_ = (GtkEntry*) gtk_entry_new ();
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_object_ref_sink (_tmp12_);
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (self->priv->entry);
#line 400 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->entry = _tmp12_;
#line 401 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp13_ = self->priv->entry;
#line 401 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp14_ = gtk_widget_get_style_context ((GtkWidget*) _tmp13_);
#line 401 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_style_context_add_class (_tmp14_, "contacts-entry");
#line 402 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp15_ = self->priv->entry;
#line 402 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp15_, GTK_ALIGN_FILL);
#line 403 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp16_ = self->priv->entry;
#line 403 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp16_, TRUE);
#line 406 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp17_ = self->priv->entry;
#line 406 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_entry_set_width_chars (_tmp17_, 4);
#line 408 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp18_ = self->priv->entry;
#line 408 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp18_);
#line 410 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp19_ = self->priv->combo;
#line 410 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp19_, TRUE);
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp20_ = self->priv->entry;
#line 411 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp20_, TRUE);
#line 413 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp21_ = self->priv->combo;
#line 413 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_show ((GtkWidget*) _tmp21_);
#line 415 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp22_ = self->priv->combo;
#line 415 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_signal_connect_object (_tmp22_, "changed", (GCallback) _contacts_typecombo_combo_changed_gtk_combo_box_changed, self, 0);
#line 416 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp23_ = self->priv->entry;
#line 416 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_signal_connect_object ((GtkWidget*) _tmp23_, "focus-out-event", (GCallback) _contacts_typecombo_entry_focus_out_event_gtk_widget_focus_out_event, self, 0);
#line 417 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp24_ = self->priv->entry;
#line 417 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_signal_connect_object (_tmp24_, "activate", (GCallback) _contacts_typecombo_entry_activate_gtk_entry_activate, self, 0);
#line 418 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp25_ = self->priv->entry;
#line 418 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_signal_connect_object ((GtkWidget*) _tmp25_, "key-release-event", (GCallback) _contacts_typecombo_entry_key_release_gtk_widget_key_release_event, self, 0);
#line 382 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (renderer);
#line 382 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return self;
#line 2773 "contacts-types.c"
}


ContactsTypeCombo* contacts_typecombo_new (ContactsTypeSet* type_set) {
#line 382 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return contacts_typecombo_construct (CONTACTS_TYPE_TYPECOMBO, type_set);
#line 2780 "contacts-types.c"
}


static void contacts_typecombo_finish_custom (ContactsTypeCombo* self) {
	gboolean _tmp0_ = FALSE;
	gchar* text = NULL;
	GtkEntry* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GtkComboBox* _tmp13_ = NULL;
	GtkEntry* _tmp14_ = NULL;
#line 421 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 422 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = self->priv->custom_mode;
#line 422 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (!_tmp0_) {
#line 423 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return;
#line 2801 "contacts-types.c"
	}
#line 425 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->custom_mode = FALSE;
#line 426 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = self->priv->entry;
#line 426 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 426 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 426 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	text = _tmp3_;
#line 428 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = text;
#line 428 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (g_strcmp0 (_tmp4_, "") != 0) {
#line 2817 "contacts-types.c"
		GtkTreeIter iter = {0};
		ContactsTypeSet* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GtkTreeIter _tmp7_ = {0};
		GtkTreeIter _tmp8_ = {0};
		GtkComboBox* _tmp9_ = NULL;
		GtkTreeIter _tmp10_ = {0};
#line 430 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = self->priv->type_set;
#line 430 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp6_ = text;
#line 430 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typeset_add_custom_label (_tmp5_, _tmp6_, &_tmp7_);
#line 430 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		iter = _tmp7_;
#line 432 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp8_ = iter;
#line 432 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		self->priv->last_active = _tmp8_;
#line 433 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp9_ = self->priv->combo;
#line 433 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp10_ = iter;
#line 433 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		gtk_combo_box_set_active_iter (_tmp9_, &_tmp10_);
#line 2843 "contacts-types.c"
	} else {
		GtkComboBox* _tmp11_ = NULL;
		GtkTreeIter _tmp12_ = {0};
#line 435 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp11_ = self->priv->combo;
#line 435 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp12_ = self->priv->last_active;
#line 435 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		gtk_combo_box_set_active_iter (_tmp11_, &_tmp12_);
#line 2853 "contacts-types.c"
	}
#line 438 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp13_ = self->priv->combo;
#line 438 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_show ((GtkWidget*) _tmp13_);
#line 439 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp14_ = self->priv->entry;
#line 439 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_widget_hide ((GtkWidget*) _tmp14_);
#line 421 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_free0 (text);
#line 2865 "contacts-types.c"
}


static void contacts_typecombo_entry_activate (ContactsTypeCombo* self) {
#line 442 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 443 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typecombo_finish_custom (self);
#line 2874 "contacts-types.c"
}


static gboolean contacts_typecombo_entry_key_release (ContactsTypeCombo* self, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkEventKey* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 446 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 446 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 447 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = event;
#line 447 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = _tmp0_->keyval;
#line 447 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp1_ == ((guint) GDK_KEY_Escape)) {
#line 2892 "contacts-types.c"
		GtkEntry* _tmp2_ = NULL;
#line 448 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp2_ = self->priv->entry;
#line 448 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		gtk_entry_set_text (_tmp2_, "");
#line 449 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		contacts_typecombo_finish_custom (self);
#line 2900 "contacts-types.c"
	}
#line 451 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = TRUE;
#line 451 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2906 "contacts-types.c"
}


static gboolean contacts_typecombo_entry_focus_out_event (ContactsTypeCombo* self, GdkEventFocus* event) {
	gboolean result = FALSE;
#line 454 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 454 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 455 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typecombo_finish_custom (self);
#line 456 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	result = FALSE;
#line 456 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	return result;
#line 2922 "contacts-types.c"
}


static void contacts_typecombo_combo_changed (ContactsTypeCombo* self, GtkComboBox* combo) {
	gboolean _tmp0_ = FALSE;
	GtkTreeIter iter = {0};
	GtkComboBox* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	gboolean _tmp3_ = FALSE;
#line 459 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 459 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (combo != NULL);
#line 460 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = self->priv->in_manual_change;
#line 460 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp0_) {
#line 461 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		return;
#line 2942 "contacts-types.c"
	}
#line 463 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->modified = TRUE;
#line 465 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = combo;
#line 465 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = gtk_combo_box_get_active_iter (_tmp1_, &_tmp2_);
#line 465 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	iter = _tmp2_;
#line 465 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	if (_tmp3_) {
#line 2954 "contacts-types.c"
		ContactsTypeSet* _tmp4_ = NULL;
		GtkTreeIter _tmp5_ = {0};
		gboolean _tmp6_ = FALSE;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp4_ = self->priv->type_set;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp5_ = iter;
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		_tmp6_ = contacts_typeset_is_custom (_tmp4_, &_tmp5_);
#line 466 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
		if (_tmp6_) {
#line 2966 "contacts-types.c"
			GtkEntry* _tmp7_ = NULL;
			GtkEntry* _tmp8_ = NULL;
			GtkComboBox* _tmp9_ = NULL;
#line 467 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			self->priv->custom_mode = TRUE;
#line 468 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp7_ = self->priv->entry;
#line 468 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			gtk_widget_show ((GtkWidget*) _tmp7_);
#line 469 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp8_ = self->priv->entry;
#line 469 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 470 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp9_ = combo;
#line 470 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			gtk_widget_hide ((GtkWidget*) _tmp9_);
#line 2984 "contacts-types.c"
		} else {
			GtkTreeIter _tmp10_ = {0};
#line 472 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			_tmp10_ = iter;
#line 472 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			self->priv->last_active = _tmp10_;
#line 473 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
			g_signal_emit_by_name (self, "changed");
#line 2993 "contacts-types.c"
		}
	}
}


static void contacts_typecombo_set_from_iter (ContactsTypeCombo* self, GtkTreeIter* iter) {
	GtkTreeIter _tmp0_ = {0};
	GtkComboBox* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
#line 478 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 478 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (iter != NULL);
#line 479 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->in_manual_change = TRUE;
#line 480 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = *iter;
#line 480 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->last_active = _tmp0_;
#line 481 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = self->priv->combo;
#line 481 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = *iter;
#line 481 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_combo_box_set_active_iter (_tmp1_, &_tmp2_);
#line 482 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv->in_manual_change = FALSE;
#line 483 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->modified = FALSE;
#line 3023 "contacts-types.c"
}


void contacts_typecombo_set_active (ContactsTypeCombo* self, FolksAbstractFieldDetails* details) {
	GtkTreeIter iter = {0};
	ContactsTypeSet* _tmp0_ = NULL;
	FolksAbstractFieldDetails* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeIter _tmp3_ = {0};
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 486 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (details != NULL);
#line 488 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = self->priv->type_set;
#line 488 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = details;
#line 488 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typeset_lookup_type (_tmp0_, _tmp1_, &_tmp2_);
#line 488 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	iter = _tmp2_;
#line 489 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = iter;
#line 489 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typecombo_set_from_iter (self, &_tmp3_);
#line 3049 "contacts-types.c"
}


void contacts_typecombo_set_to (ContactsTypeCombo* self, const gchar* type) {
	GtkTreeIter iter = {0};
	ContactsTypeSet* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeIter _tmp3_ = {0};
#line 492 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 492 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (type != NULL);
#line 494 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = self->priv->type_set;
#line 494 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp1_ = type;
#line 494 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typeset_lookup_type_by_string (_tmp0_, _tmp1_, &_tmp2_);
#line 494 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	iter = _tmp2_;
#line 495 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = iter;
#line 495 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typecombo_set_from_iter (self, &_tmp3_);
#line 3075 "contacts-types.c"
}


void contacts_typecombo_update_details (ContactsTypeCombo* self, FolksAbstractFieldDetails* details) {
	GtkTreeIter iter = {0};
	GtkComboBox* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	ContactsTypeSet* _tmp2_ = NULL;
	FolksAbstractFieldDetails* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
#line 498 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (self != NULL);
#line 498 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_return_if_fail (details != NULL);
#line 500 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp0_ = self->priv->combo;
#line 500 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	gtk_combo_box_get_active_iter (_tmp0_, &_tmp1_);
#line 500 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	iter = _tmp1_;
#line 501 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp2_ = self->priv->type_set;
#line 501 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp3_ = details;
#line 501 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_tmp4_ = iter;
#line 501 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typeset_update_details (_tmp2_, _tmp3_, &_tmp4_);
#line 3104 "contacts-types.c"
}


static void contacts_typecombo_class_init (ContactsTypeComboClass * klass) {
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	contacts_typecombo_parent_class = g_type_class_peek_parent (klass);
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_type_class_add_private (klass, sizeof (ContactsTypeComboPrivate));
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	G_OBJECT_CLASS (klass)->finalize = contacts_typecombo_finalize;
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	g_signal_new ("changed", CONTACTS_TYPE_TYPECOMBO, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3117 "contacts-types.c"
}


static void contacts_typecombo_instance_init (ContactsTypeCombo * self) {
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self->priv = CONTACTS_TYPECOMBO_GET_PRIVATE (self);
#line 3124 "contacts-types.c"
}


static void contacts_typecombo_finalize (GObject* obj) {
	ContactsTypeCombo * self;
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CONTACTS_TYPE_TYPECOMBO, ContactsTypeCombo);
#line 372 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (self->priv->type_set);
#line 373 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (self->priv->combo);
#line 374 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	_g_object_unref0 (self->priv->entry);
#line 371 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-types.vala"
	G_OBJECT_CLASS (contacts_typecombo_parent_class)->finalize (obj);
#line 3140 "contacts-types.c"
}


GType contacts_typecombo_get_type (void) {
	static volatile gsize contacts_typecombo_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_typecombo_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ContactsTypeComboClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) contacts_typecombo_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ContactsTypeCombo), 0, (GInstanceInitFunc) contacts_typecombo_instance_init, NULL };
		GType contacts_typecombo_type_id;
		contacts_typecombo_type_id = g_type_register_static (gtk_grid_get_type (), "ContactsTypeCombo", &g_define_type_info, 0);
		g_once_init_leave (&contacts_typecombo_type_id__volatile, contacts_typecombo_type_id);
	}
	return contacts_typecombo_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



